import { Component } from '@angular/core';
import { LinkService } from '../service/link.service';
import { RecordModel } from 'pocketbase';
import { NavbarComponent } from '../navbar/navbar.component';
import { Router, RouterLink } from '@angular/router';
import { MatRow, MatTableModule } from '@angular/material/table';
import { MatCardModule } from '@angular/material/card';
import { Link } from '../models/link';
import { MatButtonModule } from '@angular/material/button';
import { MatDialog, MatDialogModule } from '@angular/material/dialog';
import { ConfirmationModalComponent } from '../confirmation-modal/confirmation-modal.component';
import { MatSnackBar } from '@angular/material/snack-bar';

@Component({
  selector: 'app-dashboard',
  imports: [NavbarComponent, MatTableModule, MatCardModule, MatButtonModule],
  templateUrl: './dashboard.component.html',
  styleUrl: './dashboard.component.css'
})
export class DashboardComponent {
  public links: Link[] = [];
  displayedColumns: string[] = ['id', 'name', 'link', 'shortLink', 'actions'];

  constructor(private linkService: LinkService, private router: Router, private dialog: MatDialog, private snackBar: MatSnackBar) { };

  copyLink(id: string) {
    navigator.clipboard.writeText(this.getShortLink(id));
  }

  getShortLink(id: string): string {
    return "https://" + window.location.hostname + '/' + id;
  }

  goToLink(link: Link) {
    this.dialog.open(ConfirmationModalComponent, {
      data: {
        title: "Are you sure?",
        description: "Are you sure that you want to open " + link.link + " now?",
      },
    }).afterClosed().subscribe((accepted: Boolean) => {
      if (accepted) {
        this.router.navigate([link.id]);
      }
    });
  }

  ngOnInit(): void {
    this.linkService.getLinks().then(links => {
      this.links = links;
    });

  }

  createLink() {
    this.router.navigate(['create-link']);
  }

  deleteLink(link: Link) {
    this.dialog.open(ConfirmationModalComponent, {
      data: {
        title: "Are you sure?",
        description: "Are you sure that you want to delete " + link.name + "?",
      }
    }).afterClosed().subscribe((accepted: boolean) => {
      if (accepted) {
        this.linkService.deleteLink(link.id).catch(() => {
          const errorNotification = this.snackBar.open("Something went wrong.");
          setTimeout(() => {
            errorNotification.dismiss();
          }, 5000);
        });

        this.links = this.links.filter(givenLink => {
          return givenLink.id != link.id;
        });

        const notification = this.snackBar.open(link.name + " was deleted.");
        setTimeout(() => {
          notification.dismiss();
        }, 2000);
      }
    });
  }
}
